pub struct Stderr { /* private fields */ }Expand description
A handle to the standard error stream of a process.
For more information, see the io::stderr method.
Note: Windows Portability Considerations
When operating in a console, the Windows implementation of this stream does not support non-UTF-8 byte sequences. Attempting to write bytes that are not valid UTF-8 will return an error.
In a process with a detached console, such as one using
#![windows_subsystem = "windows"], or in a child process spawned from such a process,
the contained handle will be null. In such cases, the standard library’s Read and
Write will do nothing and silently succeed. All other I/O operations, via the
standard library or via raw Windows API calls, will fail.
Implementations
Sourceimpl Stderr
impl Stderr
1.0.0 · Sourcepub fn lock(&self) -> StderrLock<'static> ⓘ
pub fn lock(&self) -> StderrLock<'static> ⓘ
Locks this handle to the standard error stream, returning a writable guard.
The lock is released when the returned lock goes out of scope. The
returned guard also implements the Write trait for writing data.
Examples
use std::io::{self, Write};
fn foo() -> io::Result<()> {
let stderr = io::stderr();
let mut handle = stderr.lock();
handle.write_all(b"hello world")?;
Ok(())
}Trait Implementations
1.63.0 · Sourceimpl AsFd for Stderr
impl AsFd for Stderr
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>
impl AsLockedWrite for Stderr
impl AsLockedWrite for Stderr
type Write<'w> = StderrLock<'w>
type Write<'w> = StderrLock<'w>
fn as_locked_write(&mut self) -> <Stderr as AsLockedWrite>::Write<'_> ⓘ
fn as_locked_write(&mut self) -> <Stderr as AsLockedWrite>::Write<'_> ⓘ
1.70.0 · Sourceimpl IsTerminal for Stderr
impl IsTerminal for Stderr
Sourcefn is_terminal(&self) -> bool
fn is_terminal(&self) -> bool
true if the descriptor/handle refers to a terminal/tty. Read moreimpl IsTerminal for Stderr
impl IsTerminal for Stderr
fn is_terminal(&self) -> bool
fn is_terminal(&self) -> bool
true if the descriptor/handle refers to a terminal/tty.impl IsTerminal for Stderr
impl IsTerminal for Stderr
fn is_terminal(&self) -> bool
fn is_terminal(&self) -> bool
true if the descriptor/handle refers to a terminal/tty. Read moreSourceimpl StdioExt for Stderr
impl StdioExt for Stderr
Sourcefn set_fd<T>(&mut self, fd: T) -> Result<(), Error>
fn set_fd<T>(&mut self, fd: T) -> Result<(), Error>
stdio_swap)fd. Read more1.48.0 · Sourceimpl Write for &Stderr
impl Write for &Stderr
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Sourcefn flush(&mut self) -> Result<(), Error>
fn flush(&mut self) -> Result<(), Error>
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
write_all_vectored)impl Write for &Stderr
impl Write for &Stderr
1.0.0 · Sourceimpl Write for Stderr
impl Write for Stderr
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize, Error>
fn write(&mut self, buf: &[u8]) -> Result<usize, Error>
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
can_vector)Sourcefn flush(&mut self) -> Result<(), Error>
fn flush(&mut self) -> Result<(), Error>
Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
write_all_vectored)impl Write for Stderr
impl Write for Stderr
impl RawStream for Stderr
impl RefUnwindSafe for Stderr
impl UnwindSafe for Stderr